@@ -1,20 +1,11 @@
 // Copyright (C) 2019,2020 Sebastian Dröge <sebastian@centricular.com>
 // Copyright (C) 2019 Jordan Petridis <jordan@centricular.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
+// SPDX-License-Identifier: MPL-2.0
 
 use crate::parser_utils::{end_of_line, timecode, TimeCode};
 use nom::IResult;
@@ -78,9 +69,9 @@ fn scc_payload_item(s: &[u8]) -> IResult<&[u8], (u8, u8)> {
         "invalid SCC payload item",
         map(take_while_m_n(4, 4, is_hex_digit), |s: &[u8]| {
             let hex_to_u8 = |v: u8| match v {
-                v if v >= b'0' && v <= b'9' => v - b'0',
-                v if v >= b'A' && v <= b'F' => 10 + v - b'A',
-                v if v >= b'a' && v <= b'f' => 10 + v - b'a',
+                v if (b'0'..=b'9').contains(&v) => v - b'0',
+                v if (b'A'..=b'F').contains(&v) => 10 + v - b'A',
+                v if (b'a'..=b'f').contains(&v) => 10 + v - b'a',
                 _ => unreachable!(),
             };
 
