@@ -1,19 +1,10 @@
 // Copyright (C) 2020 Mathieu Duponchelle <mathieu@centricular.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
+// SPDX-License-Identifier: MPL-2.0
 
 use gst::glib;
 use gst::prelude::*;
@@ -53,8 +44,8 @@ fn eia608_to_text(cc_data: u16) -> String {
     unsafe {
         let bufsz = ffi::eia608_to_text(std::ptr::null_mut(), 0, cc_data);
         let mut data = Vec::with_capacity((bufsz + 1) as usize);
-        data.set_len(bufsz as usize);
         ffi::eia608_to_text(data.as_ptr() as *mut _, (bufsz + 1) as usize, cc_data);
+        data.set_len(bufsz as usize);
         String::from_utf8_unchecked(data)
     }
 }
@@ -213,10 +204,7 @@ impl State {
     ) {
         self.check_erase_display(element, bufferlist);
 
-        let (fps_n, fps_d) = (
-            *self.framerate.numer() as u64,
-            *self.framerate.denom() as u64,
-        );
+        let (fps_n, fps_d) = (self.framerate.numer() as u64, self.framerate.denom() as u64);
 
         let pts = (self.last_frame_no * gst::ClockTime::SECOND)
             .mul_div_round(fps_d, fps_n)
@@ -566,8 +554,8 @@ impl TtToCea608 {
         };
 
         let (fps_n, fps_d) = (
-            *state.framerate.numer() as u64,
-            *state.framerate.denom() as u64,
+            state.framerate.numer() as u64,
+            state.framerate.denom() as u64,
         );
 
         let frame_no = pts.mul_div_round(fps_n, fps_d).unwrap().seconds();
@@ -616,10 +604,6 @@ impl TtToCea608 {
         }
 
         if state.mode == Cea608Mode::PopOn {
-            if state.erase_display_frame_no.is_some() {
-                state.erase_display_frame_no = None;
-                state.erase_display_memory(element, mut_list);
-            }
             state.resume_caption_loading(element, mut_list);
             state.cc_data(element, mut_list, erase_non_displayed_memory());
         } else if state.mode == Cea608Mode::PaintOn {
@@ -664,7 +648,7 @@ impl TtToCea608 {
                 if j == 0 {
                     prepend_space = self.open_line(
                         element,
-                        &mut state,
+                        state,
                         settings,
                         chunk,
                         mut_list,
@@ -672,7 +656,7 @@ impl TtToCea608 {
                         row as i32,
                         line.carriage_return,
                     );
-                } else if self.open_chunk(element, &mut state, chunk, mut_list, col) {
+                } else if self.open_chunk(element, state, chunk, mut_list, col) {
                     prepend_space = false;
                     col += 1;
                 }
@@ -761,7 +745,7 @@ impl TtToCea608 {
 
                             self.open_line(
                                 element,
-                                &mut state,
+                                state,
                                 settings,
                                 chunk,
                                 mut_list,
@@ -798,6 +782,8 @@ impl TtToCea608 {
         }
 
         if state.mode == Cea608Mode::PopOn {
+            /* No need to erase the display at this point, end_of_caption will be equivalent */
+            state.erase_display_frame_no = None;
             state.end_of_caption(element, mut_list);
         }
 
@@ -951,8 +937,8 @@ impl TtToCea608 {
                 let mut state = self.state.lock().unwrap();
 
                 let (fps_n, fps_d) = (
-                    *state.framerate.numer() as u64,
-                    *state.framerate.denom() as u64,
+                    state.framerate.numer() as u64,
+                    state.framerate.denom() as u64,
                 );
 
                 let (timestamp, duration) = e.get();
@@ -1069,7 +1055,7 @@ impl ObjectImpl for TtToCea608 {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: Lazy<Vec<glib::ParamSpec>> = Lazy::new(|| {
             vec![
-                glib::ParamSpec::new_enum(
+                glib::ParamSpecEnum::new(
                     "mode",
                     "Mode",
                     "Which mode to operate in",
@@ -1077,7 +1063,7 @@ impl ObjectImpl for TtToCea608 {
                     DEFAULT_MODE as i32,
                     glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_PLAYING,
                 ),
-                glib::ParamSpec::new_int(
+                glib::ParamSpecInt::new(
                     "origin-row",
                     "Origin row",
                     "Origin row, (-1=automatic)",
@@ -1086,7 +1072,7 @@ impl ObjectImpl for TtToCea608 {
                     DEFAULT_ORIGIN_ROW,
                     glib::ParamFlags::READWRITE | gst::PARAM_FLAG_MUTABLE_PLAYING,
                 ),
-                glib::ParamSpec::new_uint(
+                glib::ParamSpecUInt::new(
                     "origin-column",
                     "Origin column",
                     "Origin column",
@@ -1158,6 +1144,8 @@ impl ObjectImpl for TtToCea608 {
     }
 }
 
+impl GstObjectImpl for TtToCea608 {}
+
 impl ElementImpl for TtToCea608 {
     fn metadata() -> Option<&'static gst::subclass::ElementMetadata> {
         static ELEMENT_METADATA: Lazy<gst::subclass::ElementMetadata> = Lazy::new(|| {
@@ -1178,11 +1166,11 @@ impl ElementImpl for TtToCea608 {
             {
                 let caps = caps.get_mut().unwrap();
 
-                let s = gst::Structure::new_empty("text/x-raw");
+                let s = gst::Structure::builder("text/x-raw").build();
                 caps.append_structure(s);
 
                 let s = gst::Structure::builder("application/x-json")
-                    .field("format", &"cea608")
+                    .field("format", "cea608")
                     .build();
                 caps.append_structure(s);
             }
@@ -1201,8 +1189,8 @@ impl ElementImpl for TtToCea608 {
             );
 
             let caps = gst::Caps::builder("closedcaption/x-cea-608")
-                .field("format", &"raw")
-                .field("framerate", &framerate)
+                .field("format", "raw")
+                .field("framerate", framerate)
                 .build();
 
             let src_pad_template = gst::PadTemplate::new(
@@ -1219,6 +1207,7 @@ impl ElementImpl for TtToCea608 {
         PAD_TEMPLATES.as_ref()
     }
 
+    #[allow(clippy::single_match)]
     fn change_state(
         &self,
         element: &Self::Type,
