@@ -1,19 +1,10 @@
 // Copyright (C) 2018 Sebastian Dröge <sebastian@centricular.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
+// SPDX-License-Identifier: MPL-2.0
 
 use gst::glib;
 use gst::prelude::*;
@@ -44,7 +35,7 @@ fn test_encode() {
         0x81, 0x7f, 0xff, 0x74, 0x00, 0x00, 0x1c,
     ];
 
-    let expected_output = b"File Format=MacCaption_MCC V1.0\r\n\
+    let expected_output = format!("File Format=MacCaption_MCC V1.0\r\n\
 \r\n\
 ///////////////////////////////////////////////////////////////////////////////////\r\n\
 // Computer Prompting and Captioning Company\r\n\
@@ -83,23 +74,21 @@ fn test_encode() {
 ///////////////////////////////////////////////////////////////////////////////////\r\n\
 \r\n\
 UUID=14720C04-857D-40E2-86FC-F080DE44CE74\r\n\
-Creation Program=GStreamer MCC Encoder 0.7.1\r\n\
+Creation Program=GStreamer MCC Encoder {}\r\n\
 Creation Date=Thursday, December 27, 2018\r\n\
 Creation Time=17:34:47\r\n\
 Time Code Rate=30DF\r\n\
 \r\n\
-11:12:13;14	T52S524F67ZZ72F4QRFF0222FE8CFFOM739181656E67817FFF74ZZ1CZ\r\n";
+11:12:13;14	T52S524F67ZZ72F4QRFF0222FE8CFFOM739181656E67817FFF74ZZ1CZ\r\n", env!("CARGO_PKG_VERSION"));
 
     let mut h = gst_check::Harness::new("mccenc");
     {
         let enc = h.element().expect("could not create encoder");
-        enc.set_property("uuid", &"14720C04-857D-40E2-86FC-F080DE44CE74")
-            .unwrap();
+        enc.set_property("uuid", "14720C04-857D-40E2-86FC-F080DE44CE74");
         enc.set_property(
             "creation-date",
-            &glib::DateTime::new_utc(2018, 12, 27, 17, 34, 47.0).unwrap(),
-        )
-        .unwrap();
+            glib::DateTime::from_utc(2018, 12, 27, 17, 34, 47.0).unwrap(),
+        );
     }
 
     h.set_src_caps_str(
@@ -142,6 +131,6 @@ Time Code Rate=30DF\r\n\
     let map = buf.map_readable().expect("Couldn't map buffer readable");
     assert_eq!(
         std::str::from_utf8(map.as_ref()),
-        std::str::from_utf8(expected_output.as_ref())
+        Ok(expected_output.as_str()),
     );
 }
